---
title: "Globant Code Fixer Agent: #1 on SWE-Bench Lite - Dec 19, 2024"
---

### Speakers: Marcelo Pérez Jodal, Gaston Milano

### Biography of the speakers:

Marcelo Pérez Jodal is an AI Engineer at GeneXus with a strong background in AI and software engineering. He developed Code Fixer, State-of-the-Art software maintenance AI Agent System capable of locating and fixing bugs within a project repository. Utilizing leading benchmarks like SWE-Bench and creating proprietary ones. He is also a Gold Medalist in the Mathematical Olympiads of Uruguay.

Gaston Milano is the CTO at GeneXus, with extensive experience in software architecture and development, particularly in Model-Driven Development. With over 17 years of involvement in GeneXus, Gastón has deep expertise in software development and AI.

### Abstract:

In today’s competitive tech landscape, speed and accuracy are key to delivering exceptional software solutions. Globant’s Code Fixer AI Agent has redefined the way we approach bug resolution by achieving the #1 spot on SWE-Bench Lite, one of the most challenging software engineering benchmarks. Built on the AG2 multi-agent architecture, this AI-driven agent is capable of fixing bugs in just 2.65 minutes with an impressive 48.33% resolution rate. In this talk, we’ll dive deep into the inner workings of AG2’s architecture behind their agents, demonstrate real-world bug-fixing with production code, and explore how the team optimized the system for both speed and precision.

#### Talk Recording: https://www.youtube.com/watch?v=X3rnDgpLgww
